@@ -7,6 +7,7 @@ import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlElement;
 import javax.xml.bind.annotation.XmlRootElement;
+import javax.xml.bind.annotation.XmlSchemaType;
 import javax.xml.bind.annotation.XmlType;
 
 
@@ -48,6 +49,7 @@ public class IGuestSessionDirectoryCopy {
     protected String source;
     @XmlElement(required = true)
     protected String destination;
+    @XmlSchemaType(name = "string")
     protected List<DirectoryCopyFlag> flags;
 
     /**
