@@ -7,6 +7,7 @@ import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlElement;
 import javax.xml.bind.annotation.XmlRootElement;
+import javax.xml.bind.annotation.XmlSchemaType;
 import javax.xml.bind.annotation.XmlType;
 
 
@@ -46,6 +47,7 @@ public class IMediumCloneTo {
     protected String _this;
     @XmlElement(required = true)
     protected String target;
+    @XmlSchemaType(name = "string")
     protected List<MediumVariant> variant;
     @XmlElement(required = true)
     protected String parent;
