@@ -5,6 +5,7 @@ import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlElement;
 import javax.xml.bind.annotation.XmlRootElement;
+import javax.xml.bind.annotation.XmlSchemaType;
 import javax.xml.bind.annotation.XmlType;
 
 
@@ -49,8 +50,10 @@ public class IVirtualBoxCreateMedium {
     @XmlElement(required = true)
     protected String location;
     @XmlElement(required = true)
+    @XmlSchemaType(name = "string")
     protected AccessMode accessMode;
     @XmlElement(required = true)
+    @XmlSchemaType(name = "string")
     protected DeviceType aDeviceTypeType;
 
     /**
